Learn R Programming

dogesr (version 0.5.2)

doges.years: Sub-dataset with the list of doges, their family and when it happened.

Description

A dataset with doge data and the years their reign started and ended.

Usage

data("doges.years")

Arguments

Value

A dataframe with the columns Doge, Century, Start, End, Family, Years

Author

J. J. Merelo

Details

It's essentially the original dataset doges dogesrdogesr, minus data referring to dogaresse, and leaves just data for the doges, eliminating also the "raw" columns.

References

See Also

link{doges}

Examples

Run this code
library(dogesr)
data("doges.years")
summary(doges.years$Years)

Run the code above in your browser using DataLab