Learn R Programming

dogesr (version 0.5.2)

family.colors: Pre-assigned colors for every type of family

Description

Load family.colors into the environment, assigning a color to every type of family.

Usage

data("family.colors")

Arguments

Value

List that assigns a fixed color for every type of family

  • Key: family type as in family.type.

  • Value: color chosen more or less related to the type.

Examples

Run this code
library(dogesr)
data("family.types")
data("family.colors")

# Which color corresponds to the type of the Dandolo family?
family.colors[[family.types[["Dandolo"]]]]

Run the code above in your browser using DataLab