Learn R Programming

dogesr (version 0.5.2)

family.types: Load data for Venetian family types into the environment

Description

Load family.types into the environment

Usage

data("families")

Arguments

Value

A list with every noble family in the republic of Venice, organized as

  • Key: family name.

  • Value: type of family: Estinte, Vecchie, Apostoliche, Evangeliche, Ducali, Nuove, Nuovissime, Soldo; this last name is not standard, and simply describe those who paid to be included into the Maggior Consiglio. This describes how they accessed nobility.

Main design decision here is that this can be used as external index for the type of family.

Examples

Run this code
library(dogesr)
data("families")

# Which type was the Dandolo family?
family.types[["Dandolo"]]

# Which families bought their way into the nobility
family.types == "Soldo"

# The families that actually "made doge"
unique(data.doges$Family.doge)

# And their types
family.types[unique(data.doges$Family.doge)]

# Families that had either doge or dogaresse
unique( c(data.doges$Family.doge,data.doges$Family.dogaressa))

Run the code above in your browser using DataLab