Learn R Programming

dogesr (version 0.5.2)

marriage.graph: Data on doges' matrimonial links

Description

Matrimonial links as an igraph object; it includes doges' marriages, as well as their fathers', when available.

Usage

marriage.graph()

Arguments

Value

A list that can be used as an igraph object, with noble family names as vertices and edges indicating links

Author

J. J. Merelo

Details

The result of calling the function is an unfiltered igraph object, which you can use to plot the doges social network. Nodes are families, or "casate", and links indicate a wedding has taken place between the two families. Some attributes are added to the nodes, with a color code for easy plotting.

References

See Also

link{doges}

Examples

Run this code
library(dogesr)
library(igraph)
all.matrimonial.links <- marriage.graph()

# All families linked to the Contarinis
incident(all.matrimonial.links,as.numeric(V(all.matrimonial.links)["Contarini"]))

Run the code above in your browser using DataLab