doges.years: Sub-dataset with the list of doges, their family and when it happened.
Description
A dataset with doge data and the years their reign started and ended.
Usage
data("doges.years")
Arguments
Value
A dataframe with the columns Doge, Century, Start, End, Family, Years
Author
J. J. Merelo
Details
It's essentially the original dataset doges dogesrdogesr, minus data referring to dogaresse, and leaves just data for the doges, eliminating also the "raw" columns.