powered by
Load family.colors into the environment, assigning a color to every type of family.
family.colors
data("family.colors")
List that assigns a fixed color for every type of family
Key: family type as in family.type.
family.type
Value: color chosen more or less related to the type.
library(dogesr) data("family.types") data("family.colors") # Which color corresponds to the type of the Dandolo family? family.colors[[family.types[["Dandolo"]]]]
Run the code above in your browser using DataLab